---
tags:
  - CrowdStrike
  - Process Execution
  - Web Browser

hide:
  - navigation
  - tags
---

# What web browsers were running at a given time?

**ID**: Q1019


**Approaches to Answer**

-  [Collect process executions in Crowdstrike event search [Q1019.10]](#collect-process-executions-in-crowdstrike-event-search)
    - CrowdStrike records process executions in ProcessRollup event.
    - Tags: <span class="dfiqTag">CrowdStrike</span> <span class="dfiqTag">Process Execution</span>

# Approaches

!!! Note
    There are often multiple ways to approach answering a question.
    This section explains the approaches considered, how they work, and any
    benefits or drawbacks to each. All these approaches have different pros
    and cons. They can be used individually or in conjunction.

## Collect process executions in Crowdstrike event search
### 🗂️ Explanation
CrowdStrike is a detection platform, not a logging platform, so not all ProcessRollup events might be logged.

#### References
 - https://www.crowdstrike.com/blog/understanding-indicators-attack-ioas-power-event-stream-processing-crowdstrike-falcon/

### 📝 Notes

Each approach comes with certain caveats or limitations. These can often
be tacit knowledge or assumed that "everyone knows that" (even though they
don't). This can lead to incorrect assumptions and analysis.
Explicitly stating what is covered and not covered by the approach reduces
ambiguity.

!!! success "Covered"

     - Mac, Linux and Windows systems with the Falcon Agent
     - Chrome, Firefox, Safari, and Edge web browsers

!!! failure "Not Covered"

     - Other browsers (including Chromium)
     - One of those four browsers, but have had their process name changed


### 💾 Data

The following data source(s) are needed for this approach to the question.


  - CrowdStrike: ProcessRollup

### ⚙️ Processors

A processor is what takes the [data](#💾-data) collected and processes it in
some way to produce structured data for an investigator to review. Multiple
processor options can be defined, as there are often multiple programs capable
of doing similar processing. Plaso is an example of a processor (it processes
raw artifacts into a timeline). After the data is processed, additional analysis
steps may be needed to answer the question.

The following processors can process the raw data specified above. Explicit
instructions on how to run the processor are *not* included here, but any
relevant configuration options are.


=== "Splunk"
    More information on [Splunk](https://forensics.wiki/splunk).


    #### 📊 Analysis

    After processing the raw data, further analysis steps are necessary to answer
    the question. After loading Splunk's output into one of these
    analysis platforms, use the following steps to refine the data to answer the
    question.


    Splunk-Query

    1. Query filtering the known browsers in execution event logs.
      - Type: splunk-query
      - Value: ComputerName="{hostname}" event_simpleName=ProcessRollup* ImageFileName IN ("*chrome*", "*firefox*", "*safari*", "*edge*") | table _time, CommandLine, ImageFileName

